<?xml version="1.0"?>

<!-- PC用、テストXSLT変換 -->

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:it="http://www.piedey.co.jp/xmlns/modulaf/interim"
  xmlns:sd="http://www.piedey.co.jp/xmlns/modulaf/sitedef"
  xmlns:wd="http://www.piedey.co.jp/xmlns/modulaf/worddef"
  xmlns:wr="http://www.piedey.co.jp/xmlns/modulaf/wordref"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:trackback="http://madskills.com/public/xml/rss/module/trackback/"
  xmlns:dc="http://purl.org/dc/elements/1.1/"
  xmlns:xhtml="http://www.w3.org/1999/xhtml"
  xmlns:peru="http://webservices.amazon.com/AWSECommerceService/2011-08-01"
  xmlns="http://www.w3.org/1999/xhtml"
  exclude-result-prefixes="it sd wd wr xhtml peru">

	<xsl:output method="html" 
		encoding="UTF-8" omit-xml-declaration="no" />

  <!--
  doctype-public="-//W3C//DTD HTML 4.01//EN"
  doctype-system="http://www.w3.org/TR/html4/strict.dtd"
  -->

  <xsl:param name="thisUri" />
	<xsl:param name="hostUriPath" />
	<xsl:param name="encodedRelativeURIWithoutFragmentIdentifier" />
	<xsl:param name="mf_addbase" />
	<xsl:param name="mf_dbase" />

	<xsl:variable name="pageClass" select="/it:modulafContent/@pageClass" />
	<xsl:variable name="sitedef" select="document(string(/it:modulafContent/@sitedef))" />
	<xsl:variable name="words" select="$sitedef/sd:siteDefinition/sd:term" />
	<xsl:variable name="group" select="$sitedef/sd:siteDefinition/sd:group[@pageClass=$pageClass]" />

	<!-- よく使われ、文脈で変化しない値を変数に入れておく -->
	<xsl:variable name="primaryCode" select="//it:module[@primary='true']/it:keyword/it:item[position()=last()]/@code" />
	<xsl:variable name="contentID" select="//it:module[@primary='true']/it:contentID" />
	<xsl:variable name="keywordName" select="//it:module[@primary='true']/it:keyword/it:item[position()=last()]/it:title" />

	<!-- 属性、コメント、テキストはデフォルトで素通し -->
	<xsl:template match="@*|comment()|text()">
		<xsl:copy><xsl:apply-templates select="@*|*|comment()|text()"></xsl:apply-templates></xsl:copy>
	</xsl:template>

	<!-- rdf, trackback, dcの接頭辞の要素はデフォルトで素通し -->
	<xsl:template match="rdf:*|trackback:*|dc:*" >
		<xsl:copy><xsl:apply-templates select="@*|*|comment()|text()"></xsl:apply-templates></xsl:copy>
	</xsl:template>

	<!-- rdf:RDF要素はコメントの中に埋め込む要素なので、名前空間の宣言を付け直す -->
	<xsl:template match="rdf:RDF" >
		<xsl:text disable-output-escaping="yes">
		&lt;rdf:RDF
			xmlns:rdf = "http://www.w3.org/1999/02/22-rdf-syntax-ns#"
			xmlns:trackback = "http://madskills.com/public/xml/rss/module/trackback/"
			xmlns:dc = "http://purl.org/dc/elements/1.1/" >
		</xsl:text>
		<xsl:apply-templates select="@*|*|comment()|text()"></xsl:apply-templates>
		<xsl:text disable-output-escaping="yes">
		&lt;/rdf:RDF>
		</xsl:text>
	</xsl:template>

	<!-- 不必要な名前空間宣言が出力されてしまう問題(MSXMLのバグ?)を回避するためのhack -->
	<xsl:template match="*">
		<xsl:element name="{name()}">
			<xsl:apply-templates select="@*|*|comment()|text()"/>
		</xsl:element>
	</xsl:template>

	<!-- これらの要素を空要素タグとして出力させるhack -->
	<xsl:template match="xhtml:br|xhtml:hr|xhtml:img|xhtml:base|xhtml:meta|xhtml:link|xhtml:param|xhtml:area|xhtml:input|xhtml:col">
		<xsl:text disable-output-escaping="yes">&lt;</xsl:text>
		<xsl:value-of select="name()" />
		<xsl:for-each select = "@*">
			<xsl:text> </xsl:text>
			<xsl:value-of disable-output-escaping="yes" select="name()" />
			<xsl:text>=</xsl:text>
			<xsl:text disable-output-escaping="yes">"</xsl:text>
			<xsl:value-of select="." />
			<xsl:text disable-output-escaping="yes">"</xsl:text>
		</xsl:for-each>
		<xsl:text disable-output-escaping="yes"> /></xsl:text>
	</xsl:template>

	<!-- 属性値にマクロが書けないことへの対策 -->
	<xsl:template match="it:attribute">
		<xsl:attribute name="{it:name}"><xsl:apply-templates select="it:value/*|it:value/text()" /></xsl:attribute>
	</xsl:template>

	<xsl:template name="contactlist">
		<xsl:param name="list" />
		<xsl:param name="title" />
		<xsl:param name="pclass" />
		<xsl:for-each select = "$list">
			<p>
				<xsl:attribute name="class"><xsl:value-of select="$pclass" /></xsl:attribute>
				<xsl:value-of select="$title" />: 
				<xsl:apply-templates select="it:name/*|it:name/text()" />
				<xsl:if test="it:email[1]/@pngImageUri" >
					<img class="contact" >
						<xsl:attribute name="src"><xsl:value-of select="it:email[1]/@pngImageUri" /></xsl:attribute>
						<xsl:attribute name="alt"><xsl:value-of select="$words/wd:contact" /></xsl:attribute>
					</img>
				</xsl:if>
			</p>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="sd:*">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />
		<xsl:param name="pictureWidth" />
		<xsl:param name="attachedFileNumber" />
		<xsl:param name="fragmentIdentifier" />

		<xsl:choose>
			<xsl:when test = "name(.) = 'sd:pictureWidth'"><xsl:value-of select='$pictureWidth'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:attachedFileNumber'"><xsl:value-of select='$attachedFileNumber'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:fragmentIdentifier'"><xsl:value-of select='$fragmentIdentifier'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:hostUriPath'"><xsl:value-of select='$hostUriPath'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:thisUri'"><xsl:value-of select='$thisUri'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:encodedRelativeURIWithoutFragmentIdentifier'"><xsl:value-of select='$encodedRelativeURIWithoutFragmentIdentifier'/></xsl:when>
			<xsl:when test = "name(.) = 'sd:count'">
				<span class="countNumber"><xsl:value-of select='$count'/></span>
			</xsl:when>
			<xsl:when test = "name(.) = 'sd:keywordName'">
				<xsl:value-of select='$keywordName'/>
			</xsl:when>
			<xsl:when test = "name(.) = 'sd:keywordIdentifier'">
				<xsl:value-of select='$keywordIdentifier'/>
			</xsl:when>
			<xsl:when test = "name(.) = 'sd:contentIdentifier'">
				<xsl:value-of select='$contentIdentifier'/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates>
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
					<xsl:with-param name="pictureWidth" select= "$pictureWidth" />
					<xsl:with-param name="attachedFileNumber" select= "$attachedFileNumber" />
					<xsl:with-param name="fragmentIdentifier" select= "$fragmentIdentifier" />
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

  <xsl:template match="it:xhtml">
      <xsl:value-of disable-output-escaping="yes" select="."/>
  </xsl:template>

  <xsl:template match="it:whiteSeparatorBetweenParagraphs">
		<div class="spaceBetweenPara">
		</div>
	</xsl:template>

	<xsl:template name="supplyTagetAttribute">
		<xsl:param name="contentIdentifier" />
		<xsl:if test="number(substring($contentIdentifier,1,1)) = 0 or number(substring($contentIdentifier,1,1)) >= 5">
			<xsl:attribute name="target">_blank</xsl:attribute>
		</xsl:if>
	</xsl:template>

	<xsl:template match="it:attachedFileMenu">
		<p class="attachMenuForNormal"><a href="{it:uri}"><xsl:value-of select="it:description" /></a></p>
	</xsl:template>

	<xsl:template match="it:pictureFileMenu">
		<xsl:variable name="fileNumber" select="@fileNumber" />
		<xsl:variable name="fragmentID" select="concat('F',$fileNumber)" />
		<xsl:variable name="contentIdentifier" select="ancestor::it:module/it:contentID" />

		<p class="attachMenu">
			<span class="attachMenu" id="{$fragmentID}">
				<a>
					<xsl:attribute name="href">
						<xsl:apply-templates select="$group/sd:picturePageURI">
							<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
							<xsl:with-param name="attachedFileNumber" select= "$fileNumber" />
							<xsl:with-param name="fragmentIdentifier" select= "$fragmentID" />
							<xsl:with-param name="pictureWidth" select= "it:sizes/it:size[@suggestedSize = 'true']/@width" />
						</xsl:apply-templates>
					</xsl:attribute>

					<xsl:call-template name="supplyTagetAttribute">
						<xsl:with-param name="contentIdentifier" select="$contentIdentifier" />
					</xsl:call-template>

					<xsl:apply-templates select="it:description/*|it:description/text()" />
					<img src="{it:thumbNailUri}" alt="{it:description}" />
				</a>
				<span class="attachMenuItem">
					<xsl:for-each select = "it:sizes/it:size">
						<xsl:choose>
							<!-- 注意: リスト最初の1個はサムネール画像と見なして生成せず飛ばすが、 -->
							<!--       リストに1個しか画像を含まない場合は最初の1個を生成する -->
							<xsl:when test="position() = last()" >
								[<a>
									<xsl:attribute name="href">
										<xsl:apply-templates select="$group/sd:picturePageURI">
											<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
											<xsl:with-param name="attachedFileNumber" select= "$fileNumber" />
											<xsl:with-param name="fragmentIdentifier" select= "$fragmentID" />
											<xsl:with-param name="pictureWidth" select= "''" />
										</xsl:apply-templates>
									</xsl:attribute>
									<xsl:call-template name="supplyTagetAttribute">
										<xsl:with-param name="contentIdentifier" select="$contentIdentifier" />
									</xsl:call-template>
									<xsl:value-of select="@width" />x<xsl:value-of select="@height" />
								</a>]
							</xsl:when>
							<xsl:when test="position() != 1" >
								[<a>
									<xsl:attribute name="href">
										<xsl:apply-templates select="$group/sd:picturePageURI">
											<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
											<xsl:with-param name="attachedFileNumber" select= "$fileNumber" />
											<xsl:with-param name="fragmentIdentifier" select= "$fragmentID" />
											<xsl:with-param name="pictureWidth" select= "@width" />
										</xsl:apply-templates>
									</xsl:attribute>
									<xsl:call-template name="supplyTagetAttribute">
										<xsl:with-param name="contentIdentifier" select="$contentIdentifier" />
									</xsl:call-template>
									<xsl:value-of select="@width" />x<xsl:value-of select="@height" />
								</a>]
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</span>
			</span>
		</p>
	</xsl:template>

	<!-- サイト定義ファイル内の1個のメニュー定義からメニューを生成 -->
	<xsl:template name="createOneMenu">
		<a>
			<xsl:attribute name = "href">
				<xsl:apply-templates select="sd:URI">
					<xsl:with-param name="keywordIdentifier" select="$primaryCode" />
					<xsl:with-param name="contentIdentifier" select="$contentID" />
				</xsl:apply-templates>
			</xsl:attribute>
			<xsl:attribute name = "title">
				<xsl:apply-templates select="sd:description" />
			</xsl:attribute>
			<xsl:apply-templates select="sd:name" />
		</a>
	</xsl:template>

	<!-- サイト定義ファイル内のメニュー定義からメニューを生成 -->
	<xsl:template match="it:menu">
		<xsl:call-template name="horizontalLine" />
		<p>
			<xsl:for-each select = "$group/sd:menu/sd:item">
				[<xsl:call-template name="createOneMenu"/>]
			</xsl:for-each>
      [<a target="_blank" rel="nofollow">
        <xsl:attribute name = "href">
          <xsl:choose>
            <!-- 本当はかなり危ういいい加減な判定 -->
            <xsl:when test="contains($thisUri,'?')">
              <xsl:value-of select="$thisUri" />&amp;ua=PRINT
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$thisUri" />?ua=PRINT
            </xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
        印刷用ページ
      </a>]
		</p>
	</xsl:template>

	<xsl:template match="it:administrator">
		<xsl:if test="//it:pageInfo/it:administrator">
			<xsl:call-template name="contactlist">
				<xsl:with-param name="list" select="//it:pageInfo/it:administrator" />
				<xsl:with-param name="title"><xsl:value-of select="$words/wd:administrator" /></xsl:with-param>
				<xsl:with-param name="pclass">author</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<!-- ヘッダでGoogle Mapsのスクリプトを読み込むことをリクエスト -->
	<xsl:template match="it:googleMapsRequied">
		<!-- ヘッダで意識するものなので、ここでは何もしない -->
	</xsl:template>
  <!-- ヘッダでFlash Loaderのスクリプトを読み込むことをリクエスト -->
  <xsl:template match="it:flashRequied">
    <!-- ヘッダで意識するものなので、ここでは何もしない -->
  </xsl:template>

  <xsl:template name="wordRefMain">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />
		<xsl:variable name="localName" select= "local-name(.)" />
		<xsl:variable name="targetNodes" select= "$words/wd:*[local-name(.) = $localName]" />

		<xsl:choose>
			<xsl:when test="@keywordIdentifier">
				<xsl:apply-templates select="$targetNodes">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "@keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="$targetNodes">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="wr:*">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />

		<xsl:choose>
			<!-- パラメータcontentIdentifierが指定されていない場合
				//it:module[@primary='true']/it:contentIDの内容を代用品として与える
				-->
			<xsl:when test="$contentIdentifier = '' and //it:module[@primary='true']/it:contentID">
				<xsl:call-template name="wordRefMain">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "//it:module[@primary='true']/it:contentID/*|//it:module[@primary='true']/it:contentID/text()" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$contentIdentifier = '' and //it:module/it:contentID[1]">
				<xsl:call-template name="wordRefMain">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "//it:module/it:contentID[1]/*|//it:module/it:contentID[1]/text()" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="wordRefMain">
					<xsl:with-param name="count" select= "$count" />
					<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
					<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template match="wd:*">
		<xsl:param name="count" />
		<xsl:param name="keywordIdentifier" />
		<xsl:param name="contentIdentifier" />
		<xsl:param name="attachedFileNumber" />
		<xsl:param name="fragmentIdentifier" />
		<xsl:param name="pictureWidth" />
		<xsl:apply-templates>
			<xsl:with-param name="count" select= "$count" />
			<xsl:with-param name="keywordIdentifier" select= "$keywordIdentifier" />
			<xsl:with-param name="contentIdentifier" select= "$contentIdentifier" />
			<xsl:with-param name="attachedFileNumber" select= "$attachedFileNumber" />
			<xsl:with-param name="fragmentIdentifier" select= "$fragmentIdentifier" />
			<xsl:with-param name="pictureWidth" select= "$pictureWidth" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template name="horizontalLine">
		<div class="horizontalLine">
		</div>
	</xsl:template>

	<xsl:template name="keywordSubOnlyText">
		<xsl:param name="itemlist" />
		<xsl:for-each select = "$itemlist">
			<xsl:if test = "position() != 1">
				<xsl:text>→</xsl:text>
			</xsl:if>
			<xsl:value-of select="it:title"/>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="keywordSub">
		<xsl:param name="itemlist" />
		<xsl:for-each select = "$itemlist">
			<xsl:if test = "position() != 1">
				<xsl:text>→</xsl:text>
			</xsl:if>
			<a>
				<xsl:choose>
					<xsl:when test = "position() = last()">
						<xsl:attribute name="class">itemListKWLinkLast</xsl:attribute>
					</xsl:when> 
					<xsl:otherwise>
						<xsl:attribute name="class">itemListKWLink</xsl:attribute>
					</xsl:otherwise> 
				</xsl:choose>
				<xsl:choose>
					<xsl:when test = "@code = ''">
						<xsl:attribute name = "href"><xsl:value-of select="$group/sd:siteTopURI" /></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name = "href">
							<xsl:apply-templates select="$group/sd:keywordTopURI">
								<xsl:with-param name="keywordIdentifier" select= "@code" />
							</xsl:apply-templates>
						</xsl:attribute>
					</xsl:otherwise> 
				</xsl:choose>
				<xsl:attribute name="title"><xsl:apply-templates select="it:summary/*|it:summary/text()" /></xsl:attribute>
				<xsl:apply-templates select="it:title/*|it:title/text()"/>
			</a>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="it:contentNavigation">
		<table class="nextprev" summary="next and previous contents">
			<tr><td class="nextPrevIntable"><xsl:value-of select="$words/wd:keyword" />【
				<xsl:call-template name="keywordSub">
					<xsl:with-param name="itemlist" select= "it:keyword[1]/it:item" />
				</xsl:call-template>】</td></tr>

			<tr><td class="nextPrevIntable">【<xsl:value-of select="$keywordName" />】の次の<xsl:value-of select="$words/wd:content" /></td></tr>
			<tr><td class="nextPrevIntableForDeep">
				<xsl:choose>
					<xsl:when test = "it:keyword[1]/it:item[position() = last()]/it:next">
						<table summary="next content" class="nextPrevIntable">
							<xsl:call-template name="referListSub">
								<xsl:with-param name="list" select="it:keyword[1]/it:item[position() = last()]/it:next" />
							</xsl:call-template>
						</table>
					</xsl:when>
					<xsl:otherwise>
						<span class="noItems">(ありません)</span>
					</xsl:otherwise>
				</xsl:choose>
			</td></tr>

			<tr><td class="nextPrevIntable">【<xsl:value-of select="$keywordName" />】の前の<xsl:value-of select="$words/wd:content" /></td></tr>
			<tr><td class="nextPrevIntableForDeep">
				<xsl:choose>
					<xsl:when test = "it:keyword[1]/it:item[position() = last()]/it:prev">
						<table summary="prev content" class="nextPrevIntable">
							<xsl:call-template name="referListSub">
								<xsl:with-param name="list" select="it:keyword[1]/it:item[position() = last()]/it:prev" />
							</xsl:call-template>
						</table>
					</xsl:when>
					<xsl:otherwise>
						<span class="noItems">(ありません)</span>
					</xsl:otherwise>
				</xsl:choose>
			</td></tr>

			<xsl:variable name="allContentsListForKeyword" select="$group/sd:menu/sd:item[@type='allContentsListForKeyword']" />
			<xsl:if test = "$allContentsListForKeyword">
				<tr>
				<td class="nextPrevIntable">
					<xsl:for-each select = "$allContentsListForKeyword">
						<xsl:call-template name="createOneMenu" />
					</xsl:for-each>
				</td></tr>
			</xsl:if>

			<xsl:variable name="coverPageForKeyword" select="$group/sd:menu/sd:item[@type='coverPageForKeyword']" />
			<xsl:if test = "$coverPageForKeyword">
				<tr>
				<td class="nextPrevIntable">
					<xsl:for-each select = "$coverPageForKeyword">
						<xsl:call-template name="createOneMenu" />
					</xsl:for-each>
				</td></tr>
			</xsl:if>
		</table>
	</xsl:template>

	<xsl:template match="it:adsByGoogle">
		<script type="text/javascript">
      <xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>
      google_ad_client = "<xsl:value-of select="it:adsByGoogleId" />";
      google_ad_slot = "<xsl:value-of select="it:adsByGoogleSlot" />";
      google_ad_width = 120;
      google_ad_height = 600;
      //<xsl:text disable-output-escaping="yes">--></xsl:text>
    </script>
		<script type="text/javascript"
		src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
		</script>
	</xsl:template>

	<xsl:template match="it:adsByGoogleSearch">
		<!-- SiteSearch Google -->
		<form method="get" action="http://www.google.co.jp/custom" target="_top" class="googleSearch">
		<p>
		<a href="http://www.google.com/">
		<img src="http://www.google.com/logos/Logo_25blk.gif" border="0" alt="Google" align="middle"/></a>
		<input type="hidden" name="domains">
			<xsl:attribute name="value"><xsl:value-of select="it:host" /></xsl:attribute>
		</input>
		<input type="text" name="q" size="31" maxlength="255" value=""></input>
		<input type="submit" name="sa" value="検索" class="searchButton"></input>

		<input type="radio" name="sitesearch" value=""></input>
		<font size="-1" color="#ffffff">Web</font>
		<input type="radio" name="sitesearch" checked="checked">
			<xsl:attribute name="value"><xsl:value-of select="it:host" /></xsl:attribute>
		</input>
		<font size="-1" color="#ffffff"><xsl:value-of select="it:host" /></font>

		<input type="hidden" name="client">
			<xsl:attribute name="value"><xsl:value-of select="it:adsByGoogleId" /></xsl:attribute>
		</input>
		<input type="hidden" name="forid" value="1"></input>
		<input type="hidden" name="ie" value="UTF-8"></input>
		<input type="hidden" name="oe" value="UTF-8"></input>
		<input type="hidden" name="flav" value="0000"></input>
		<input type="hidden" name="sig" value="27EaP6qg0rOCh9ES"></input>
		<input type="hidden" name="cof">
			<xsl:attribute name="value">GALT:#CCCCEE;GL:1;DIV:#FFFFFF;VLC:CCEECC;AH:center;BGC:204080;LBGC:112266;ALC:EEEE88;LC:EEEE88;T:E0E0FF;GFNT:EEEE66;GIMP:EEEE66;L:<xsl:value-of select="$hostUriPath" />title001.gif;S:<xsl:value-of select="$hostUriPath" />;FORID:1</xsl:attribute>
		</input>
		<input type="hidden" name="hl" value="ja"></input>
		</p>
		</form>
		<!-- SiteSearch Google -->
	</xsl:template>

	<xsl:template match="it:gamerTag">
		<iframe scrolling="no" frameBorder="0" height="140" width="204">
				<xsl:attribute name="src">http://gamercard.xbox.com/<xsl:value-of select="@name" />.card</xsl:attribute>
		</iframe>
	</xsl:template>

	<xsl:template name="keyword">
		<span class="itemListKW">
			<xsl:call-template name="keywordSub">
				<xsl:with-param name="itemlist" select= "it:keyword[1]/it:item" />
			</xsl:call-template>
		</span>
	</xsl:template>

	<xsl:template name="errorPeruItem">
		<tr>
		<td>
		<h2><xsl:value-of select="it:error/it:title"/></h2>
		<xsl:apply-templates select="it:error/it:body/*|it:error/it:body/text()" />
		</td>
		</tr>
	</xsl:template>

	<xsl:template name="normalShortPeruItem">
		<tr>
		<td class="peruShort">
			<p class="shortPeruPicture">
			<xsl:if test="peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:URL/text()">
				<a href="{it:peruPurchaseLinkOldStyle}">
				<img class="shortPeruPicture" src="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:URL}"
					width="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:Width}"
					height="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:SmallImage/peru:Height}"
					alt="{peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Title}" 
					/></a>
				<br />
			</xsl:if>
			<a href="{it:peruPurchaseLinkOldStyle}"><xsl:value-of select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Title"/></a>
			<xsl:for-each select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Author">
				<br />
				<xsl:value-of select="."/>
			</xsl:for-each>
			<xsl:for-each select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Artist">
				<br />
				<xsl:value-of select="."/>
			</xsl:for-each>
			<xsl:for-each select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:ItemAttributes/peru:Actor">
				<br />
				<xsl:value-of select="."/>
			</xsl:for-each>
			<br />
			-----
			<xsl:if test="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestUsedPrice/peru:FormattedPrice">
				<br />
				<span class="peruShortHead">Used Price:</span><br /><xsl:value-of select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestUsedPrice/peru:FormattedPrice"/>
			</xsl:if>
			<xsl:if test="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestNewPrice/peru:FormattedPrice">
				<br />
				<span class="peruShortHead">Price:</span><br /><xsl:value-of select="peru:ItemLookupResponse/peru:Items/peru:Item/peru:OfferSummary/peru:LowestNewPrice/peru:FormattedPrice"/>
			</xsl:if>
			</p>
		</td>
		</tr>
	</xsl:template>

	<xsl:template match="it:shortPeruList">
		<xsl:if test="it:item">
			<table summary="item list">
				<xsl:for-each select = "it:item">
					<xsl:choose>
						<xsl:when test = "it:error">
							<xsl:call-template name="errorPeruItem" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="normalShortPeruItem" />
						</xsl:otherwise> 
					</xsl:choose>
				</xsl:for-each>
				<tr>
				<td class="peruShort">
				<a href="http://www.amazon.co.jp/"><img src="perulogo.gif" alt="{$words/wd:peruNameTM} Logo" /></a>
				</td>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>

	<!-- it:bodyの下に書かれたit:referList要素 (おそらくMagMLの$$ctreeによって生成されたもの) -->
	<!-- の処理を行うtemplate。referListModuleのit:referList要素はこれによって処理されない -->
	<xsl:template match="it:referList">
		<table summary="refer list">
			<!-- referList本体の作成をreferListSubテンプレートに任せる -->
			<xsl:call-template name="referListSub">
				<xsl:with-param name="list" select="it:item" />
			</xsl:call-template>
		</table>
	</xsl:template>

	<xsl:template match="it:trackBackList">
		<xsl:if test="it:item">
			<table summary="trackback list">
			<tr>
			<th class="tblist">
			<h2 class="trackBackTitle"><xsl:value-of select="$words/wd:trackback" />一覧</h2>
			</th>
			</tr>
			<xsl:for-each select = "it:item">
				<xsl:sort select="position()" order="descending" />
				<tr>
				<td class="tblist">
				<table class="tbentry" summary="trackback item">
					<tr>
					<td class="intable">
						<table class="tbIntableWithBorder" summary="trackback header">
						<tr>
							<td class="tbdate"><xsl:value-of select='it:date'/></td>
							<td class="tb"><xsl:value-of select='it:title'/></td>
							<td class="tbfrom"><span class="tbfrom">From: </span><xsl:value-of select='it:from'/></td>
						</tr>
						</table>
					</td>
					</tr>
					<tr>
					<td class="tbbody">
					<div>
					<p><xsl:value-of select='it:digest'/> 
					<a>
					<xsl:attribute name="href"><xsl:value-of select='it:uri'/></xsl:attribute>
					続きを読む</a>
					</p>
					</div>
					</td>
					</tr>
				</table>
				</td>
				</tr>
			</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template match="it:trackBackURI">
		<table class="tburl"  summary="trackback URI">
			<xsl:for-each select = "it:item">
				<tr>
				<td class="tburl">
					<xsl:apply-templates select='*|text()'>
						<xsl:with-param name="contentIdentifier" select= "../../it:contentID" />
					</xsl:apply-templates></td>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>

	<!-- キーワードとカウントを含むレアウト用内部テーブルを生成する -->
	<xsl:template name="keywordAndCount">
		<table class="intable" summary="sub header">
			<tr>
				<xsl:if test="it:keyword">
					<td class="intableKeyword">
						<xsl:call-template name="keyword" />
					</td>
				</xsl:if>
				<xsl:if test="it:totalAccessCount">
					<td class="intableCount">
						<xsl:apply-templates select="$words/wd:totalAccessCount">
							<xsl:with-param name="count" select= "it:totalAccessCount[1]" />
						</xsl:apply-templates>
					</td>
				</xsl:if>
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="contentTitle">
		<xsl:choose>
			<xsl:when test="@primary='true' and it:contentID">
				<h1 class="contentFullTitle">
					<a class="itemListLink">
						<xsl:attribute name = "href">
							<xsl:apply-templates select="$group/sd:contentURI">
								<xsl:with-param name="contentIdentifier" select= "it:contentID[1]" />
							</xsl:apply-templates>
						</xsl:attribute>
						<xsl:apply-templates select='it:title/*|it:title/text()'/>
					</a>
				</h1>
			</xsl:when>
			<xsl:when test="@primary='true' and not(it:contentID)">
				<h1 class="contentFullTitle">
					<xsl:apply-templates select='it:title/*|it:title/text()'/>
				</h1>
			</xsl:when>
			<xsl:otherwise>
				<h2>
					<xsl:apply-templates select='it:title/*|it:title/text()'/>
				</h2>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- 箱形のモジュールのヘッダを生成する -->
	<xsl:template name="boxedModuleHeader">
		<tr>
			<td class="intable">
				<table class="intableWithBorder" summary="module header">
					<tr>
						<xsl:if test="it:iconPicture[1]">
							<td>
								<p class="titlePicture">
									<img class="titlePicture">
										<xsl:attribute name="src"><xsl:value-of select="it:iconPicture[1]" /></xsl:attribute>
										<xsl:attribute name="alt"><xsl:value-of select="$words/wd:iconPicture" /></xsl:attribute>
									</img>
								</p>
							</td>
						</xsl:if>
						<xsl:if test="it:date[1]">
							<td class="date"><xsl:value-of select='it:date[1]'/></td>
						</xsl:if>
						<td class="intable">
							<table class="intable" summary="main header">
								<xsl:if test="it:keyword or it:totalAccessCount">
									<tr>
										<td class="intable">
											<xsl:call-template name="keywordAndCount" />
										</td>
									</tr>
								</xsl:if>
								<tr>
									<td class="intableContents">
										<xsl:call-template name="contentTitle" />
									</td>
								</tr>
							</table>
						</td>
					</tr>
				</table>
			</td>
		</tr>
	</xsl:template>

	<xsl:template name="boxedModule">
		<xsl:param name="tableClass" />

		<xsl:choose>
			<xsl:when test="it:body">
				<table summary="a module">
					<xsl:if test="string-length($tableClass) &gt; 0">
						<xsl:attribute name="class"><xsl:value-of select="$tableClass"/></xsl:attribute>
					</xsl:if>

					<xsl:call-template name="boxedModuleHeader" />

					<xsl:if test="it:author">
						<tr>
							<td class="intable">
								<xsl:call-template name="contactlist">
									<xsl:with-param name="list" select="it:author" />
									<xsl:with-param name="title"><xsl:value-of select="$words/wd:author" /></xsl:with-param>
									<xsl:with-param name="pclass">author</xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
					</xsl:if>
					<tr>
						<td>
							<div>
								<xsl:apply-templates select="it:body/*|it:body/text()" />
							</div>
						</td>
					</tr>

				</table>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="it:title">
					<xsl:call-template name="contentTitle" />
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:apply-templates select="it:shortPeruList"/>

		<xsl:apply-templates select="it:contentNavigation" />

		<xsl:apply-templates select="it:trackBackList" />

		<xsl:apply-templates select="it:trackBackURI" />

		<xsl:apply-templates select="it:adsByGoogle" />

		<xsl:apply-templates select="it:adsByGoogleSearch" />
		
		<xsl:apply-templates select="it:gamerTag" />
	</xsl:template>

	<!-- プレーンな(ボックスに入っていない)モジュールを生成する本体 -->
	<xsl:template name="planeModuleSub">
		<xsl:if test="it:iconPicture[1]">
			<p class="titlePicture">
				<img class="titlePicture">
					<xsl:attribute name="src"><xsl:value-of select="it:iconPicture[1]" /></xsl:attribute>
					<xsl:attribute name="alt"><xsl:value-of select="$words/wd:iconPicture" /></xsl:attribute>
				</img>
			</p>
		</xsl:if>
		<xsl:if test="it:date[1]">
			<p><xsl:value-of select='it:date[1]'/></p>
		</xsl:if>
		<xsl:if test="it:keyword or it:totalAccessCount">
			<xsl:call-template name="keywordAndCount" />
		</xsl:if>
		<xsl:if test="it:title">
			<xsl:call-template name="contentTitle" />
		</xsl:if>
		<xsl:if test="it:author">
			<xsl:call-template name="contactlist">
				<xsl:with-param name="list" select="it:author" />
				<xsl:with-param name="title"><xsl:value-of select="$words/wd:author" /></xsl:with-param>
				<xsl:with-param name="pclass">author</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="it:body/*|it:body/text()" />

		<xsl:apply-templates select="it:contentNavigation" />

		<xsl:apply-templates select="it:trackBackList" />

		<xsl:apply-templates select="it:shortPeruList"/>

		<xsl:apply-templates select="it:adsByGoogle" />

		<xsl:apply-templates select="it:trackBackURI" />

		<xsl:apply-templates select="it:adsByGoogleSearch" />
		
		<xsl:apply-templates select="it:gamerTag" />
	</xsl:template>

	<!-- プレーンな(ボックスに入っていない)モジュールを生成する -->
	<!-- しかし、referListの場合はボックスが出てしまう。やむなし -->
	<xsl:template name="planeModule">
		<xsl:if test="*">
			<xsl:choose>
				<xsl:when test = "it:referList">
					<xsl:call-template name="referListModule" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="planeModuleSub" />
				</xsl:otherwise> 
			</xsl:choose>
		</xsl:if>
	</xsl:template>

	<!-- ReferListモジュール用のキーワードを生成する -->
	<xsl:template name="keywordForReferListModule">
		<table class="intable" summary="refer header">
			<tr>
				<td class="intableKeyword">
					<span class="itemListKW">
						<xsl:call-template name="keywordSub">
							<xsl:with-param name="itemlist" select= "it:keyword[1]/it:item" />
						</xsl:call-template>
					</span>
				</td>
			</tr>
		</table>
	</xsl:template>

	<!-- referListの本体を生成する共用テンプレート -->
	<xsl:template name="referListSub">
		<xsl:param name="list" />
			<xsl:for-each select = "$list">
				<tr>
					<xsl:if test="../it:item/it:rank" >
						<td class="number">
							<xsl:if test="it:rank" >
								No.<xsl:value-of select="it:rank"/>
							</xsl:if>
						</td>
					</xsl:if>
					<xsl:if test="../it:item/it:lastUpdatedDate" >
						<td class="lastUpdatedDate">
							最終更新 
							<span class="contListDate">
								<xsl:choose>
									<xsl:when test="it:lastUpdatedDate" >
											<xsl:value-of select="it:lastUpdatedDate"/>
									</xsl:when>
									<xsl:otherwise>
										(なし)
									</xsl:otherwise>
								</xsl:choose>
							</span>
						</td>
					</xsl:if>

					<xsl:if test="it:date" >
						<td class="date"><xsl:value-of select="it:date"/></td>
					</xsl:if>

					<td class="intable">
						<table class="intable" summary="refer main header">
							<xsl:if test="it:keyword[1]/it:item" >
								<tr>
									<td class="intable">
										<xsl:call-template name="keywordForReferListModule"/>
									</td>
								</tr>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="it:URI[1]" >
									<tr>
										<td class="intableContents">
											<xsl:if test="it:summary" >
												<xsl:attribute name="title"><xsl:apply-templates select="it:summary/*|it:summary/text()" /></xsl:attribute>
											</xsl:if>
											<a class="itemListLink">
												<xsl:attribute name = "href">
													<xsl:apply-templates select='it:URI/*|it:URI/text()'/>
												</xsl:attribute>
												<xsl:apply-templates select='it:title/*|it:title/text()'/>
											</a>
										</td>
									</tr>
								</xsl:when>
								<xsl:when test="it:contentID[1]" >
									<tr>
										<td class="intableContents">
											<xsl:if test="it:summary" >
												<xsl:attribute name="title"><xsl:apply-templates select="it:summary/*|it:summary/text()" /></xsl:attribute>
											</xsl:if>
											<a class="itemListLink">
												<xsl:attribute name = "href">
													<xsl:apply-templates select="$group/sd:contentURI">
														<xsl:with-param name="contentIdentifier" select= "it:contentID[1]" />
													</xsl:apply-templates>
												</xsl:attribute>
												<xsl:apply-templates select='it:title/*|it:title/text()'/>
											</a>
										</td>
									</tr>
								</xsl:when>
							</xsl:choose>
						</table>
					</td>

					<!-- カウントを独立した部屋に入れる -->
					<xsl:if test="it:totalAccessCount or it:recentlyAccessCount" >
						<td class="indivisualCount">
							<xsl:if test = "it:recentlyAccessCount">
								<span class="indivisual3DaysCount">
								<xsl:apply-templates select="$words/wd:recentlyAccessCount">
									<xsl:with-param name="count" select= "it:recentlyAccessCount[1]" />
								</xsl:apply-templates></span>
								<xsl:if test = "it:totalAccessCount">
									<br />
								</xsl:if>
							</xsl:if>
							<xsl:if test = "it:totalAccessCount">
								<span class="indivisualTotalCount">
								<xsl:apply-templates select="$words/wd:totalAccessCount">
									<xsl:with-param name="count" select= "it:totalAccessCount[1]" />
								</xsl:apply-templates></span>
							</xsl:if>
						</td>
					</xsl:if>

				</tr>
			</xsl:for-each>
	</xsl:template>

	<!-- コンテンツの参照リストのモジュールを生成する -->
	<xsl:template name="referListModule">
		<xsl:if test="it:title">
		<xsl:choose>
			<xsl:when test = "@primary = 'true'">
				<h1><xsl:apply-templates select="it:title/*|it:title/text()" /></h1>
			</xsl:when>
			<xsl:otherwise>
				<h2><xsl:apply-templates select="it:title/*|it:title/text()" /></h2>
			</xsl:otherwise> 
		</xsl:choose>
		</xsl:if>
		<xsl:if test="it:iconPicture[1]">
			<p class="titlePicture">
				<img class="titlePicture">
					<xsl:attribute name="src"><xsl:value-of select="it:iconPicture[1]" /></xsl:attribute>
					<xsl:attribute name="alt"><xsl:value-of select="$words/wd:iconPicture" /></xsl:attribute>
				</img>
			</p>
		</xsl:if>
		<xsl:if test="it:date[1]">
			<p><xsl:value-of select='it:date[1]'/></p>
		</xsl:if>
		<!--
		<xsl:if test="it:keyword or it:totalAccessCount">
			<xsl:call-template name="keywordAndCount" />
		</xsl:if>
		-->
		<xsl:if test="it:author">
			<xsl:call-template name="contactlist">
				<xsl:with-param name="list" select="it:author" />
				<xsl:with-param name="title"><xsl:value-of select="$words/wd:author" /></xsl:with-param>
				<xsl:with-param name="pclass">author</xsl:with-param>
			</xsl:call-template>
		</xsl:if>

		<xsl:apply-templates select="it:body/*|it:body/text()" />

		<table summary="refer list">
			<!-- referList本体の作成をreferListSubテンプレートに任せる -->
			<xsl:call-template name="referListSub">
				<xsl:with-param name="list" select="it:referList/it:item" />
			</xsl:call-template>
		</table>

	</xsl:template>

  <xsl:template name="cycleUI">
    <p>
      <input type="button" onclick="cycle_prev();" value="&lt;&lt;&lt;"/>
      <span id="cyclebar1"></span>
      <span id="cyclebar2" style="color:black;">*********</span>
      <input type="button" onclick="cycle_stop();" value="||"/>
      <input type="button" onclick="cycle_next();" value=">>>"/>
    </p>
  </xsl:template>

  <!-- プレーン(ボックスに入っていない)ではない通常のモジュール -->
	<xsl:template name="normalModule">
		<xsl:param name="tableClass" />
		<xsl:if test="*">
      <div>
        <xsl:if test="@cycle">
          <xsl:attribute name="class">cycle_<xsl:value-of select="@cycle"></xsl:value-of></xsl:attribute>
          <xsl:attribute name="style">display:none;</xsl:attribute>
        </xsl:if>
        <xsl:choose>
          <xsl:when test = "it:cycleUI">
            <xsl:call-template name="cycleUI" />
          </xsl:when>
          <xsl:when test = "it:referList">
            <xsl:call-template name="referListModule" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name="boxedModule" >
              <xsl:with-param name="tableClass" select="$tableClass" />
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </div>
		</xsl:if>
	</xsl:template>

	<xsl:template name="primaryHeaderModule">
		<xsl:if test="*">
			<table class="boxed" summary="primary header">
				<tr>
					<xsl:if test="it:iconPicture">
						<td>
							<p class="titlePicture">
								<img class="titlePicture">
									<xsl:attribute name="src"><xsl:value-of select="it:iconPicture[1]" /></xsl:attribute>
									<xsl:attribute name="alt"><xsl:value-of select="$words/wd:iconPicture" /></xsl:attribute>
								</img>
							</p>
						</td>
					</xsl:if>
					<td>
						<div class="mainTitleText">
							<xsl:choose>
								<xsl:when test = "it:keyword/it:item[last()]/@code=''">
									<h1 class="maintitle"><xsl:value-of select="//it:pageInfo/it:siteName" /></h1>
								</xsl:when>
								<xsl:otherwise>
									<p class="mainTitleSupply"><xsl:value-of select="//it:pageInfo/it:siteName" /></p>
									<p><xsl:call-template name="keyword" /></p>
									<h1 class="maintitle"><xsl:value-of select="it:keyword/it:item[last()]/it:title" /></h1>
								</xsl:otherwise> 
							</xsl:choose>
						</div>
					</td>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="main">
		<xsl:call-template name="normalModule" />
	</xsl:template>

	<xsl:template name="header">
		<xsl:choose>
			<xsl:when test = "@primary = 'true'">
				<xsl:call-template name="primaryHeaderModule" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="planeModule" />
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:template>

	<xsl:template name="footer">
		<xsl:call-template name="planeModule" />
	</xsl:template>

	<xsl:template name="left">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="right">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="upper">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="lower">
		<xsl:call-template name="normalModule" >
			<xsl:with-param name="tableClass">thin</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generateDivLink">
		<xsl:param name="number" />
		<xsl:param name="label" />
		<xsl:param name="class" />
		<span class="{$class}">
			<xsl:choose>
				<xsl:when test="$number = /it:modulafContent/it:div/@number">
					<span class="divHere"><xsl:value-of select="$number" /></span>
				</xsl:when>
				<xsl:otherwise>
					<a><xsl:attribute name="href"><xsl:value-of select="$mf_dbase" />mf_d=<xsl:value-of select="$number" /></xsl:attribute><span class="divLink"><xsl:value-of select="$label" /></span></a>
				</xsl:otherwise>
			</xsl:choose>
		</span>
	</xsl:template>

	<xsl:template name="generateDivLinkRelative">
		<xsl:param name="number" />
		<xsl:param name="class" />
		<xsl:if test="$number > 1 and /it:modulafContent/it:div/@all > $number">
			<xsl:call-template name="generateDivLink">
				<xsl:with-param name="number"><xsl:value-of select="$number" /></xsl:with-param>
				<xsl:with-param name="label"><xsl:value-of select="$number" /></xsl:with-param>
				<xsl:with-param name="class"><xsl:value-of select="$class" /></xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="divNavigation">
		<xsl:if test="/it:modulafContent/it:div">
			<p><span class="divCaption">分割されたページ: </span>
				<!-- 1st item -->
				<xsl:call-template name="generateDivLink">
					<xsl:with-param name="number">1</xsl:with-param>
					<xsl:with-param name="label">1</xsl:with-param>
					<xsl:with-param name="class">divLeftMost</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="generateDivLinkRelative">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number - 2" /></xsl:with-param>
					<xsl:with-param name="class">divLeft</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="generateDivLinkRelative">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number - 1" /></xsl:with-param>
					<xsl:with-param name="class">divLeft</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="generateDivLinkRelative">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number" /></xsl:with-param>
					<xsl:with-param name="class">divCenter</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="generateDivLinkRelative">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number + 1" /></xsl:with-param>
					<xsl:with-param name="class">divRight</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="generateDivLinkRelative">
					<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@number + 2" /></xsl:with-param>
					<xsl:with-param name="class">divRight</xsl:with-param>
				</xsl:call-template>
				
				<!-- last item -->
				<xsl:if test="/it:modulafContent/it:div/@all > 1">
					<xsl:call-template name="generateDivLink">
						<xsl:with-param name="number"><xsl:value-of select="/it:modulafContent/it:div/@all" /></xsl:with-param>
						<xsl:with-param name="label"><xsl:value-of select="/it:modulafContent/it:div/@all" /></xsl:with-param>
						<xsl:with-param name="class">divRightMost</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</p>
		</xsl:if>
	</xsl:template>

	<xsl:template name="divNext">
		<xsl:if test="/it:modulafContent/it:div and (/it:modulafContent/it:div/@all > /it:modulafContent/it:div/@number)">
			<tr><td class="divNext"><a>
			<xsl:attribute name="href"><xsl:value-of select="$mf_dbase" />mf_d=<xsl:value-of select="/it:modulafContent/it:div/@number + 1" /></xsl:attribute>
			続き...
			</a></td></tr>
		</xsl:if>
	</xsl:template>

	<xsl:template match="it:trackBackAutoDiscovery">
	</xsl:template>

	<xsl:template match="/">
    <xsl:value-of disable-output-escaping="yes" select="'&lt;!DOCTYPE html>'"/>
		<html lang="ja-JP" xml:lang="ja-JP" xmlns:v="urn:schemas-microsoft-com:vml">
		<head>
		<!-- 次の1行は、ココログのリスト機能を正常に動作させるためのhack。本来は無くて良い -->
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<title><xsl:apply-templates select="//it:module[@primary='true']/it:title/*|//it:module[@primary='true']/it:title/text()"/>
			&#x20;【<xsl:call-template name="keywordSubOnlyText">
				<xsl:with-param name="itemlist" select= "//it:module[@primary='true']/it:keyword[1]/it:item" />
			</xsl:call-template>】
		</title>

		<link href="default.css" type="text/css" rel="stylesheet" />

		<link href="sitemapstyler.css" type="text/css" rel="stylesheet" />

		<xsl:if test="//it:pageInfo/it:rss">
			<link rel="alternate" type="application/rss+xml" title="RSS" >
				<xsl:attribute name="href"><xsl:apply-templates select="//it:pageInfo/it:rss/*|//it:pageInfo/it:rss/text()">
						<xsl:with-param name="keywordIdentifier" select= "//it:module[@primary='true']/it:keyword/it:item[last()]/@code" />
				</xsl:apply-templates></xsl:attribute>
			</link>
		</xsl:if>

		<xsl:if test="//it:pageInfo/it:trackBackAutoDiscovery" >
			<xsl:text disable-output-escaping="yes">&#13;&#10;&lt;!--&#13;&#10;</xsl:text>
			<xsl:apply-templates select="//it:pageInfo/it:trackBackAutoDiscovery/rdf:RDF" />
			<xsl:text disable-output-escaping="yes">&#13;&#10;-->&#13;&#10;</xsl:text>
		</xsl:if>

		<link rel="icon" href="favicon.ico" type="image/x-icon" />
		<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />

		<xsl:if test="//it:prototypeJsRequied" >
			<script type="text/javascript" src="prototype.js"></script>
		</xsl:if>

		<xsl:if test="//it:googleMapsRequied" >
		    <script type="text/javascript">
				<xsl:attribute name="src">http://maps.google.com/maps?file=api&amp;v=2&amp;key=<xsl:value-of select="/it:modulafContent/it:pageInfo/it:googleMapsKey" /></xsl:attribute>
		    </script>
			<script type="text/javascript" src="gmhelper.js"></script>
		</xsl:if>

    <xsl:if test="//it:siteMapStylerRequied" >
			<script type="text/javascript" src="sitemapstyler.js"></script>
		</xsl:if>

    <xsl:if test="//it:flashRequied" >
      <script language="text/javascript">AC_FL_RunContent = 0;</script>
      <script src="AC_RunActiveContent.js" language="javascript"></script>
    </xsl:if>

    <script type="text/javascript" src="magsite2.js"></script>

    </head>
		<body>
			<xsl:if test="//it:googleMapsRequied" >
				<xsl:attribute name="onunload">GUnload()</xsl:attribute>
			</xsl:if>

			<xsl:for-each select = "it:modulafContent/it:module[@layout='header']">
				<xsl:call-template name="header" />
			</xsl:for-each>

			<xsl:call-template name="divNavigation" />

			<xsl:variable name="leftList" select="it:modulafContent/it:module[@layout='left']" />
			<xsl:variable name="mainList" select="it:modulafContent/it:module[@layout='main']" />
			<xsl:variable name="rightList" select="it:modulafContent/it:module[@layout='right']" />

			<xsl:choose>
				<xsl:when test="count($leftList) = 0 and count($rightList) = 0">
					<table class="external" summary="main modules">
						<xsl:for-each select = "it:modulafContent/it:module[@layout='upper']">
							<tr>
								<td class="external">
									<xsl:call-template name="upper" />
								</td>
							</tr>
						</xsl:for-each>
						<xsl:for-each select = "$mainList">
							<tr>
								<td class="external">
									<xsl:call-template name="main" />
								</td>
							</tr>
						</xsl:for-each>

						<xsl:call-template name="divNext" />

						<xsl:for-each select = "it:modulafContent/it:module[@layout='lower']">
							<tr>
								<td class="external">
									<xsl:call-template name="lower" />
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="side" select="concat('externalSide', substring('SW',number(count($leftList) > 0 and count($rightList) > 0)+1,1))" />
					<table class="external" summary="main modules">
					<tr>
						<xsl:if test="count($leftList) > 0">
							<td>
								<!--<xsl:attribute name="class"><xsl:value-of select="$side" /></xsl:attribute>-->
								<!-- 以下はperuShortList使用の固定値指定 -->
								<xsl:attribute name="class">externalSideSforPeruShort</xsl:attribute>
								<table class="external" summary="left modules">
									<xsl:for-each select = "$leftList">
										<tr>
											<td class="external">
												<xsl:call-template name="left" />
											</td>
										</tr>
									</xsl:for-each>
								</table>
							</td>
						</xsl:if>
						
						<td class="externalCenter">
							<table class="external" summary="center modules">
								<xsl:for-each select = "it:modulafContent/it:module[@layout='upper']">
									<tr>
										<td class="external">
											<xsl:call-template name="upper" />
										</td>
									</tr>
								</xsl:for-each>
								<xsl:for-each select = "$mainList">
									<tr>
										<td class="external">
											<xsl:call-template name="main" />
										</td>
									</tr>
								</xsl:for-each>

								<xsl:call-template name="divNext" />

								<xsl:for-each select = "it:modulafContent/it:module[@layout='lower']">
									<tr>
										<td class="external">
											<xsl:call-template name="lower" />
										</td>
									</tr>
								</xsl:for-each>
							</table>
						</td>
						<xsl:if test="count($rightList) > 0">
							<td>
								<!--<xsl:attribute name="class"><xsl:value-of select="$side" /></xsl:attribute>-->
								<!-- 以下はAds by Google使用の固定値指定 -->
								<xsl:attribute name="class">externalSideSforADS</xsl:attribute>
								<table class="external" summary="right modules">
									<xsl:for-each select = "$rightList">
										<tr>
											<td class="external">
												<xsl:call-template name="right" />
											</td>
										</tr>
									</xsl:for-each>
								</table>
							</td>
						</xsl:if>
					</tr>
					</table>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:call-template name="divNavigation" />

			<xsl:for-each select = "it:modulafContent/it:module[@layout='footer']">
				<xsl:call-template name="footer" />
			</xsl:for-each>

			<script type="text/javascript" src="http://www.assoc-amazon.jp/s/link-enhancer?tag=autumnmagazin-22&amp;o=9">
			</script>
			<noscript>
				<img src="http://www.assoc-amazon.jp/s/noscript?tag=autumnmagazin-22" alt="" />
			</noscript>
		</body>
		</html>
	</xsl:template>

</xsl:stylesheet>
